==> apache-ignite-2.16.0-src.zip: apache-ignite-2.16.0-src/modules/core/src/main/java/org/apache/ignite/internal/management/kill/KillSnapshotCommand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.management.kill;

import org.apache.ignite.internal.management.api.ComputeCommand;
import org.apache.ignite.internal.management.kill.SnapshotCancelTask.CancelSnapshotArg;
import org.apache.ignite.internal.management.snapshot.SnapshotTaskResult;

/** */
public class KillSnapshotCommand implements ComputeCommand<CancelSnapshotArg, SnapshotTaskResult> {
    /** {@inheritDoc} */
    @Override public String description() {
        return "Kill running snapshot by snapshot name";
    }

    /** {@inheritDoc} */
    @Override public Class<KillSnapshotCommandArg> argClass() {
        return KillSnapshotCommandArg.class;
    }

    /** {@inheritDoc} */
    @Override public Class<SnapshotCancelTask> taskClass() {
        return SnapshotCancelTask.class;
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/core/src/main/java/org/apache/ignite/internal/management/kill/KillSnapshotCommand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.management.kill;

import org.apache.ignite.internal.management.api.ComputeCommand;
import org.apache.ignite.internal.management.kill.SnapshotCancelTask.CancelSnapshotArg;

/** */
public class KillSnapshotCommand implements ComputeCommand<CancelSnapshotArg, String> {
    /** {@inheritDoc} */
    @Override public String description() {
        return "Kill running snapshot by snapshot name";
    }

    /** {@inheritDoc} */
    @Override public Class<KillSnapshotCommandArg> argClass() {
        return KillSnapshotCommandArg.class;
    }

    /** {@inheritDoc} */
    @Override public Class<SnapshotCancelTask> taskClass() {
        return SnapshotCancelTask.class;
    }
}
